summaryrefslogtreecommitdiff
path: root/src/device
diff options
context:
space:
mode:
authorPeter Lawrence <[email protected]>2020-03-30 13:34:56 -0500
committerPeter Lawrence <[email protected]>2020-03-30 13:47:17 -0500
commit87f313da48aa1df4fb0566d9ad26036f06418422 (patch)
tree779a10375f37608f8fc392b6706e3757913725f7 /src/device
parent370dd1839465e71caa3024f6f2347b701a94953d (diff)
add provision for multiple configurations
Diffstat (limited to 'src/device')
-rw-r--r--src/device/usbd.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/device/usbd.h b/src/device/usbd.h
index 07163a013..71829322b 100644
--- a/src/device/usbd.h
+++ b/src/device/usbd.h
@@ -156,9 +156,9 @@ TU_ATTR_WEAK bool tud_vendor_control_complete_cb(uint8_t rhport, tusb_control_re
//------------- Configuration -------------//
#define TUD_CONFIG_DESC_LEN (9)
-// Interface count, string index, total length, attribute, power in mA
-#define TUD_CONFIG_DESCRIPTOR(_itfcount, _stridx, _total_len, _attribute, _power_ma) \
- 9, TUSB_DESC_CONFIGURATION, U16_TO_U8S_LE(_total_len), _itfcount, 1, _stridx, TU_BIT(7) | _attribute, (_power_ma)/2
+// Interface count, string index, total length, attribute, power in mA, config number
+#define TUD_CONFIG_DESCRIPTOR(_itfcount, _stridx, _total_len, _attribute, _power_ma, config_num) \
+ 9, TUSB_DESC_CONFIGURATION, U16_TO_U8S_LE(_total_len), _itfcount, config_num, _stridx, TU_BIT(7) | _attribute, (_power_ma)/2
//------------- CDC -------------//